@@ -3,11 +3,11 @@ from typing import cast
 import thot.alignment as ta
 
 from ..hmm_word_alignment_model import HmmWordAlignmentModel
-from .thot_word_alignment_model import ThotWordAlignmentModel
+from .thot_ibm1_word_alignment_model import ThotIbm1WordAlignmentModel
 from .thot_word_alignment_model_type import ThotWordAlignmentModelType
 
 
-class ThotHmmWordAlignmentModel(ThotWordAlignmentModel, HmmWordAlignmentModel):
+class ThotHmmWordAlignmentModel(ThotIbm1WordAlignmentModel, HmmWordAlignmentModel):
     @property
     def type(self) -> ThotWordAlignmentModelType:
         return ThotWordAlignmentModelType.HMM
@@ -25,7 +25,7 @@ class ThotHmmWordAlignmentModel(ThotWordAlignmentModel, HmmWordAlignmentModel):
 
     def get_alignment_probability(self, source_length: int, prev_source_index: int, source_index: int) -> float:
         # add 1 to convert the specified indices to Thot position indices, which are 1-based
-        return self._hmm_model.get_alignment_prob(prev_source_index + 1, source_length, source_index + 1)
+        return self._hmm_model.hmm_alignment_prob(prev_source_index + 1, source_length, source_index + 1)
 
     @property
     def _hmm_model(self) -> ta.HmmAlignmentModel:
